@@ -148,49 +148,56 @@ class Swab(object):
                 <div py:for="variant, vdata in sorted(data[exp.name]['variants'].items())">
                     <py:if test="variant != data[exp.name]['control']">
                         <py:for each="goal in goals">
-                            <?python
-                            difference = vdata['r'][goal] / control_data['r'][goal]
-                            ?>
-                            <p>
-                                For the <strong>$goal</strong> goal, the <strong>$variant</strong> variant resulted in
-                                <py:choose>
-                                    <span py:when="difference &gt;= 1" class="better">${'{0:.2%}'.format(difference - 1)} more conversions than the $control variant</span>
-                                    <span py:otherwise="" class="worse">${'{0:.2%}'.format(difference - 1)} fewer conversions than the $control variant</span>
-                                </py:choose>
-                            </p>
+                            <py:choose>
+                                <py:when test="control_data['r'][goal] == 0">
+                                    Insufficient data
+                                </py:when>
+                                <py:otherwise>
+                                    <?python
+                                    difference = vdata['r'][goal] / control_data['r'][goal]
+                                    ?>
+                                    <p>
+                                        For the <strong>$goal</strong> goal, the <strong>$variant</strong> variant resulted in
+                                        <py:choose>
+                                            <span py:when="difference &gt;= 1" class="better">${'{0:.2%}'.format(difference - 1)} more conversions than the $control variant</span>
+                                            <span py:otherwise="" class="worse">${'{0:.2%}'.format(difference - 1)} fewer conversions than the $control variant</span>
+                                        </py:choose>
+                                    </p>
 
-                            <ul class="simpleList">
-                                <py:choose>
-                                    <div class="confident99" py:when="vdata['confidence'][goal] &gt;= 0.99">
-                                        <li>
-                                            You have now collected enough data to be 99% certain that this conclusion is valid.
-                                        </li>
-                                        <li class="recommendation">
-                                            <py:choose>
-                                                Recommendation:
-                                                <span py:when="difference &gt;= 1">adopt $variant variant.</span>
-                                                <span py:otherwise="">adopt $control variant.</span>
-                                            </py:choose>
-                                        </li>
-                                    </div>
-                                    <div class="confident95" py:when="vdata['confidence'][goal] &gt;= 0.95">
-                                        <li>
-                                            You have collected enough data to be 95% sure that this difference is not simply due to chance factors.
-                                        </li>
-                                        <li class="recommendation">
-                                            Recommendation: <strong>let the test run for longer to be completely certain</strong>.
-                                        </li>
-                                    </div>
-                                    <div class="unconfident" py:otherwise="">
-                                        <li>
-                                            You don't have enough data to be sure yet that this difference is due to the variant you are testing or purely chance factors.
-                                        </li>
-                                        <li class="recommendation">
-                                            Recommendation: <strong>let the test run to collect more data</strong>.
-                                        </li>
-                                    </div>
-                                </py:choose>
-                            </ul>
+                                    <ul class="simpleList">
+                                        <py:choose>
+                                            <div class="confident99" py:when="vdata['confidence'][goal] &gt;= 0.99">
+                                                <li>
+                                                    You have now collected enough data to be 99% certain that this conclusion is valid.
+                                                </li>
+                                                <li class="recommendation">
+                                                    <py:choose>
+                                                        Recommendation:
+                                                        <span py:when="difference &gt;= 1">adopt $variant variant.</span>
+                                                        <span py:otherwise="">adopt $control variant.</span>
+                                                    </py:choose>
+                                                </li>
+                                            </div>
+                                            <div class="confident95" py:when="vdata['confidence'][goal] &gt;= 0.95">
+                                                <li>
+                                                    You have collected enough data to be 95% sure that this difference is not simply due to chance factors.
+                                                </li>
+                                                <li class="recommendation">
+                                                    Recommendation: <strong>let the test run for longer to be completely certain</strong>.
+                                                </li>
+                                            </div>
+                                            <div class="unconfident" py:otherwise="">
+                                                <li>
+                                                    You don't have enough data to be sure yet that this difference is due to the variant you are testing or purely chance factors.
+                                                </li>
+                                                <li class="recommendation">
+                                                    Recommendation: <strong>let the test run to collect more data</strong>.
+                                                </li>
+                                            </div>
+                                        </py:choose>
+                                    </ul>
+                                </py:otherwise>
+                            </py:choose>
                         </py:for>
                     </py:if>
                 </div>
@@ -456,10 +463,13 @@ def zscore(p, n, pc, nc):
 
     See http://20bits.com/articles/statistical-analysis-and-ab-testing/.
     """
-    return (p - pc) / sqrt(
-        (p * (1 - p) / n)
-        + (pc * (1 - pc) / nc)
-    )
+    try:
+        return (p - pc) / sqrt(
+            (p * (1 - p) / n)
+            + (pc * (1 - pc) / nc)
+        )
+    except ZeroDivisionError:
+        return float('nan')
 
 def cumulative_normal_distribution(z):
     """
